@@ -19,6 +19,13 @@
 
 #include <BluezQt/Services>
 
+// Pseudo plugin class to embed meta data
+class KIOPluginForMetaData : public QObject
+{
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.kio.slave.bluetooth" FILE "bluetooth.json")
+};
+
 extern "C" int Q_DECL_EXPORT kdemain(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
@@ -82,7 +89,7 @@ QList<KioBluetooth::Service> KioBluetooth::getSupportedServices(const QStringLis
 
 void KioBluetooth::listRemoteDeviceServices()
 {
-    infoMessage(i18n("Retrieving services..."));
+    infoMessage(i18n("Retrieving services…"));
 
     qCDebug(BLUETOOTH) << "Listing remote devices";
 
@@ -158,7 +165,7 @@ void KioBluetooth::listDevices()
 
     m_kded->startDiscovering(10 * 1000);
 
-    infoMessage(i18n("Scanning for new devices..."));
+    infoMessage(i18n("Scanning for new devices…"));
     finished();
 }
 
@@ -241,3 +248,5 @@ void KioBluetooth::setHost(const QString &hostname, quint16 port, const QString
 }
 
 Q_LOGGING_CATEGORY(BLUETOOTH, "bluedevil.kio_bluetooth")
+
+#include "kiobluetooth.moc"
